@@ -4,7 +4,8 @@ from .compute_implantation_coefficients_angle import \
 from .extract_data import Exposition
 from .inventory_T_c import estimate_inventory_with_gp_regression
 from .compute_inventory import process_file, compute_c_max, \
-    compute_inventory, DEFAULT_TIME, database_inv_sig
+    compute_inventory, DEFAULT_TIME, database_inv_sig, \
+    fetch_inventory_and_error
 
 from .plotting.plot_2d_contour import plot_Tc_map_with_subplots, \
     create_2d_inv_array
